@@ -1,8 +1,8 @@
-Index: haskell-lens-3.9.0.2/tests/doctests.hsc
+Index: haskell-lens/tests/doctests.hsc
 ===================================================================
---- haskell-lens-3.9.0.2.orig/tests/doctests.hsc	2013-06-15 13:40:30.329035355 +0200
-+++ haskell-lens-3.9.0.2/tests/doctests.hsc	2013-06-15 13:40:30.325035355 +0200
-@@ -54,9 +54,9 @@
+--- haskell-lens.orig/tests/doctests.hsc	2015-08-15 14:18:10.501591463 +0200
++++ haskell-lens/tests/doctests.hsc	2015-08-15 14:18:10.501591463 +0200
+@@ -56,9 +56,9 @@
  main :: IO ()
  main = withUnicode $ getSources >>= \sources -> doctest $
      "-isrc"
@@ -12,5 +12,5 @@ Index: haskell-lens-3.9.0.2/tests/doctests.hsc
 -  : "-optPdist/build/autogen/cabal_macros.h"
 +  : "-optPdist-ghc/build/autogen/cabal_macros.h"
    : "-hide-all-packages"
-   : map ("-package="++) deps ++ sources
- 
+ #ifdef TRUSTWORTHY
+   : "-DTRUSTWORTHY=1"
